from bs4 import BeautifulSoup
import requests
from deep_translator import GoogleTranslator

def get_country_code(country):
    url_country_codes = "https://www.scrapingbee.com/documentation/country_codes/"
    response = requests.get(url_country_codes)
    soup = BeautifulSoup(response.content,'html.parser')
    country_codes_dict = {soup.find('table').find_all('td')[a].text:soup.find('table').find_all('td')[a+1].text for a in range(0,len(soup.find('table').find_all('td'))-2)}
    country_codes_dict_lower = {c.lower():country_codes_dict[c] for c in country_codes_dict if len(country_codes_dict[c])==2}
    return country_codes_dict_lower[country.lower()]

def translate(s,origin_lang,target_lang):
    s_translated = GoogleTranslator(source=origin_lang, target=target_lang).translate(s)
    return s_translated


import sqlalchemy

def get_mssql_connection_local():
    """creates sqlalchemy connection engine to mssql database
    as defined by the MSSQL environment variables"""

    driver='ODBC Driver 17 for SQL Server'
    driver_str = '+'.join(driver.strip("\'").split(' '))
    db_name = 'MotoPfoheForecasting'

    con_str = f'mssql+pyodbc://localhost/{db_name}?driver={driver_str}'
    client = sqlalchemy.create_engine(con_str)
    return(client)


import requests
from bs4 import BeautifulSoup

def get_soup(url):

    ### need to set headers for this url, as it otherwise gives an infinite redirect loop
    headers = {
        'Accept-Encoding': 'gzip, deflate, sdch',
        'Accept-Language': 'en-US,en;q=0.8',
        'Upgrade-Insecure-Requests': '1',
        'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/56.0.2924.87 Safari/537.36',
        'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
        'Cache-Control': 'max-age=0',
        'Connection': 'keep-alive',}


    page = requests.get(
                url = url,
                headers=headers,
                verify=False,
                )
    soup = BeautifulSoup(page.content, 'html.parser')
    
    print(url)
    
    return soup